diff --git a/protocols/bgp/server/fsm_test.go b/protocols/bgp/server/fsm_test.go
index 7d040713aa74d362caae10888c5c2c2b6de3bd63..5cddf8aee4663202b1ad716e59e922486dd45019 100644
--- a/protocols/bgp/server/fsm_test.go
+++ b/protocols/bgp/server/fsm_test.go
@@ -13,8 +13,8 @@ import (
 	bnet "github.com/bio-routing/bio-rd/net"
 )
 
-// TestFSM55UpdatesIPv4 emulates receiving 255 BGP updates and withdraws. Checks route counts.
-func TestFSM100UpdatesIPv4(t *testing.T) {
+// TestFSM255UpdatesIPv4 emulates receiving 255 BGP updates and withdraws. Checks route counts.
+func TestFSM255UpdatesIPv4(t *testing.T) {
 	fsmA := newFSM(&peer{
 		addr:     bnet.IPv4FromOctets(169, 254, 100, 100),
 		routerID: bnet.IPv4FromOctets(1, 1, 1, 1).ToUint32(),